@@ -19,7 +19,7 @@ from urlparse import urlparse
 try:
     from urlparse import parse_qsl
 except ImportError:
-    from cgi import parse_qsl
+    from cgi import parse_qsl  # noqa
 
 from kombu import exceptions
 from kombu.transport import get_transport_cls
